/*** Program: Step2_codes_majorcc_subpop.sas                                                     ***/
/*** Created: August 16, 2020                                                                    ***/
/*** Program description: identified from conditions of interest from claims files/ICD-10 codes  ***/
/*** Need: dx10_&pyr. file created in  Step1_claims_based_frailty_index.sas                      ***/

libname dataout 'D:\'; * output directory - should be the same as Step 1, so that it is also where dx10_&pyr. dataset is ;

%let pyr=2016; /* Assign previous year - year all claims and indicators are based on */
%let yr=2017;  /* Assign current year - year the segments will be used               */

/*** from claims ***/
data all_codes_dx;
	set dataout.dx10_&pyr.;

	/* initialize indicator variables */
	clm_autoimmune=0; clm_raregenetic=0; clm_neurological=0; clm_intellectual=0; clm_cancer=0;

	/*** Autoimmune ***/
	clm_ai_rheumarth=0; clm_ai_psoriasis=0; clm_ai_ms=0; clm_ai_sle=0; clm_ai_mctd=0;
	clm_ai_amyloi=0; clm_ai_sclero=0; clm_ai_ibd=0; clm_ai_addison=0; clm_ai_sjogren=0;
	clm_ai_myasth=0; clm_ai_asd=0; clm_ai_anky=0; clm_ai_behcet=0; clm_ai_cidp=0; clm_ai_crest=0;
	clm_ai_uctd=0; clm_ai_pbc=0; clm_ai_psc=0; clm_ai_derma=0; clm_ai_discoid=0; clm_check_ai=0;

	if 	substr(dx,1,3) in	('M05')	 	 then clm_ai_rheumarth=1;	label clm_ai_rheumarth="Rheumatoid arthritis"; /* Rheumatoid arthritis  */
	if 	substr(dx,1,3) in	('L40')	 	 then clm_ai_psoriasis=1;	label clm_ai_psoriasis="Psoriasis/psoriatic arthritis"; /* Psoriasis/psoriatic arthritis */
	if 	dx in				('G35', 'G360', 'G361', 'G368', 'G369', 'G371', 'G372', 'G373', 'G374', 'G378', 'G379')	 then clm_ai_ms=1;	label clm_ai_ms="Multiple sclerosis and Transverse Myelitis"; /*Multiple sclerosis and Transverse Myelitis */
	if 	substr(dx,1,3) in	('M32')	 	 then clm_ai_sle=1; label clm_ai_sle="Systemic lupus erythematous (SLE)";	/*Systemic lupus erythematous (SLE) */
	if 	dx in				('M359')	 then clm_ai_mctd=1; label clm_ai_mctd="Mixed connective tissue disease";	/*Mixed connective tissue disease */
	if 	substr(dx,1,3) in	('E85')	 	 then clm_ai_amyloi=1; label clm_ai_amyloi="Amyloidosis";	/*Amyloidosis */
	if 	substr(dx,1,3) in	('M34')	 	 then clm_ai_sclero=1; label clm_ai_sclero="Scleroderma"; 	/*Scleroderma */
	if 	substr(dx,1,3) in	('K50', 'K51') then clm_ai_ibd=1; label clm_ai_ibd="Inflammatory bowel disease";	/*Inflammatory bowel disease  includes Crohn's disease and ulcerative colitis */
	if 	dx in				('E2740')	 then clm_ai_addison=1; label clm_ai_addison="Addison's disease";	/*Addison's disease */
	if 	substr(dx,1,4) in	('M350')	 then clm_ai_sjogren=1; label clm_ai_sjogren="Sjogren's syndrome";	/*Sjogren's syndrome */
	if 	substr(dx,1,4) in	('G700')	 then clm_ai_myasth=1; label clm_ai_myasth="Myasthenia gravis";	/*Myasthenia gravis */
	if 	dx in				('M061')	 then clm_ai_asd=1; label clm_ai_asd="Adult's still disease";	/*Adult's still disease */
	if 	substr(dx,1,3) in	('M45')	 	 then clm_ai_anky=1; label clm_ai_anky="Ankylosing spondylitis";	/*Ankylosing spondylitis */
	if 	dx in				('M352')	 then clm_ai_behcet=1; label clm_ai_behcet="Behcet's disease";	/*Behcet's disease */
	if 	dx in				('G6181')	 then clm_ai_cidp=1; label clm_ai_cidp="Chronic inflammatory demyelinating polyneuropathy";	/*Chronic inflammatory demyelinating polyneuropathy */
	if 	dx in				('M341')	 then clm_ai_crest=1; label clm_ai_crest="CREST syndrome";	/*CREST syndrome */
	if 	dx in				('M359')	 then clm_ai_uctd=1; label clm_ai_uctd="Undifferentiated connective tissue disease";	/*Undifferentiated connective tissue disease */
	if 	dx in				('K743')	 then clm_ai_pbc=1; label clm_ai_pbc="Primary biliary cirrhosis";	/*Primary biliary cirrhosis */
	if 	dx in				('K8301')	 then clm_ai_psc=1; label clm_ai_psc="Primary sclerosing cholangitis";	/*Primary sclerosing cholangitis */
	if 	dx in				('K830')	 then clm_ai_psc=1; label clm_check_ai="Check: Primary cholangitis";	/*Primary sclerosing cholangitis */
	if 	substr(dx,1,3) in	('M33')	 	 then clm_ai_derma=1; label clm_ai_derma="Dermatomyositis/Polymyositits";	/*Dermatomyositis/Polymyositits */
	if 	dx in				('L930')	 then clm_ai_discoid=1; label clm_ai_discoid="Discoid lupus";	/* Discoid lupus  */

	count_ai = sum(of clm_ai_:);
	if count_ai gt 0 then clm_autoimmune=1;

	/*** Rare genetic ***/
	clm_rg_cf=0; clm_rg_muscdyst=0; clm_rg_hemophilia=0; clm_rg_huntington=0; clm_rg_downsyn=0;
	clm_rg_fragile=0; clm_rg_glycogen=0; clm_rg_charcot=0; clm_rg_angelman=0; clm_rg_vonw=0;
	clm_rg_sickle=0; clm_rg_taysachs=0; clm_rg_hemochr=0; clm_rg_digeorges=0; clm_rg_criduchat=0;
	clm_rg_canavan=0; clm_rg_neurofib=0; clm_rg_pkd=0; clm_rg_prader=0; clm_rg_famil=0;
	clm_rg_turner=0; clm_rg_spinmusc=0; clm_rg_als=0; clm_check_rg=0;

	if 	dx in				('D81810', 'D841', 'E000', 'E001', 'E002', 'E009', 'E030', 'E031', 'E250', 'E258', 'E259', 'E569', 'E700', 'E701', 'E7020', 'E7021', 'E7029',
							 'E7030', 'E70310', 'E70311', 'E70318', 'E70319', 'E70320', 'E70321', 'E70328', 'E70329', 'E70330', 'E70331', 'E70338', 'E70339', 'E7039', 'E705',
							 'E708', 'E709', 'E710', 'E71110', 'E71111', 'E71118', 'E7119', 'E712', 'E71310', 'E71311', 'E71312', 'E71313', 'E71314', 'E71318', 'E7132',
							 'E7141', 'E7210', 'E7211', 'E7212', 'E7219', 'E7220', 'E7221', 'E7222', 'E7223', 'E7229', 'E723', 'E724', 'E7250', 'E7251', 'E7259', 'E728',
							 'E7420', 'E7421', 'E7429', 'E840', 'E8411', 'E8419', 'E848', 'E849')
										 then clm_rg_cf=1; label clm_rg_cf="Cystic fibrosis and other metabolic developmental disorders";	/* Cystic fibrosis and other metabolic developmental disorders */
	if 	dx in				('G710', 'G7100', 'G7101', 'G7102', 'G7109', 'G7111', 'G712') then clm_rg_muscdyst=1; label clm_rg_muscdyst="Duchenne muscular dystrophy and other muscular disorders";	/* Duchenne muscular dystrophy and other muscular disorders */
	if 	dx in				('D66')	 	 then clm_rg_hemophilia=1; label clm_rg_hemophilia="Hemophilia";	/* Hemophilia */
	if 	dx in				('G10')	 	 then clm_rg_huntington=1; label clm_rg_huntington="Huntingtons disease and other movement disorders";	/* Huntington's disease and other movement disorders */
	if 	substr(dx,1,3) in	('Q90')	 	 then clm_rg_downsyn=1; label clm_rg_downsyn="Down syndrome";	/* Down syndrome */
	if 	dx in				('Q992')	 then clm_rg_fragile=1; label clm_rg_fragile="Fragile X syndrome";	/* Fragile X syndrome */
	if 	substr(dx,1,4) in	('E740')	 then clm_rg_glycogen=1; label clm_rg_glycogen="Glycogen storage disorders";	/* Glycogen storage disorders */
	if 	dx in				('G600')	 then clm_rg_charcot=1; label clm_rg_charcot="Charcot-Marie-Tooth disease";	/* Charcot-Marie-Tooth disease */
	if 	dx in				('Q9351')	 then clm_rg_angelman=1; label clm_rg_angelman="Angelman syndrome";	/* Angelman syndrome */
	if 	dx in				('Q935')	 then clm_check_rg=1; label clm_check_rg="OtherChromosome";	/* Angelman syndrome */
	if 	dx in				('D680')	 then clm_rg_vonw=1; label clm_rg_vonw="Von Williebrand disease";	/* Von Williebrand disease */
	if 	dx in				('D5700', 'D5701', 'D5702', 'D571', 'D5720', 'D57211', 'D57212', 'D57219', 'D5740', 'D57411', 'D57412', 'D57419', 'D5780', 'D57811', 'D57812',
							 'D57819')	 then clm_rg_sickle=1; label clm_rg_sickle="Sickle cell disease";	/* Sickle cell disease */
	if 	dx in				('E7502')	 then clm_rg_taysachs=1; label clm_rg_taysachs="Tay Sachs disease";	/* Tay Sachs disease */
	if 	substr(dx,1,5) in	('E8311')	 then clm_rg_hemochr=1; label clm_rg_hemochr="Hemochromatosis";	/* Hemochromatosis */
	if 	dx in				('Q9381')	 then clm_rg_digeorges=1; label clm_rg_digeorges="DiGeorges syndrome";	/* DiGeorges syndrome */
	if 	dx in				('Q934')	 then clm_rg_criduchat=1; label clm_rg_criduchat="Cri du chat syndrome";	/* Cri du chat syndrome */
	if 	dx in				('E7529')	 then clm_rg_canavan=1; label clm_rg_canavan="Canavan disease";	/* Canavan disease */
	if 	substr(dx,1,4) in	('Q850')	 then clm_rg_neurofib=1; label clm_rg_neurofib="Neurofibromatosis";	/* Neurofibromatosis */
	if 	dx in				('Q611', 'Q612', 'Q613') then  clm_rg_pkd=1; label clm_rg_pkd="Polycystic kidney disease";	/* Polycystic kidney disease */
	if 	dx in				('Q8711')	 then clm_rg_prader=1; label clm_rg_prader="Prader Willi Syndrome";	/* Prader Willi Syndrome */
	if 	dx in				('E7801')	 then clm_rg_famil=1; label clm_rg_famil="Familial hypercholesterolemia";	/* Familial hypercholesterolemia */
	if 	substr(dx,1,3) in	('Q96')	 	 then clm_rg_turner=1; label clm_rg_turner="Turner syndrome";	/* Turner syndrome */
	if 	substr(dx,1,3) in	('G12')	 	 then clm_rg_spinmusc=1; label clm_rg_spinmusc="Spinal muscular atrophy";	/* Spinal muscular atrophy */
	if 	dx in				('G1221')	 then clm_rg_als=1; label clm_rg_als="Amyotrophic lateral sclerosis";	/* Amyotrophic lateral sclerosis */

	count_rg = sum(of clm_rg_:);
	if count_rg gt 0 then clm_raregenetic=1;

	/*** Neurological ***/
	clm_nr_spinabif=0; clm_nr_traumbrain=0; clm_nr_cerebralp=0; clm_nr_mobility=0; clm_nr_spinal=0;

	if 	dx in				('G901', 'Q000', 'Q001', 'Q002', 'Q010', 'Q011', 'Q012', 'Q018', 'Q019', 'Q02', 'Q030', 'Q031', 'Q038', 'Q039', 'Q040', 'Q041', 'Q042', 'Q043', 'Q044', 'Q045',
							 'Q046', 'Q048', 'Q049', 'Q050', 'Q051', 'Q052', 'Q053', 'Q054', 'Q055', 'Q056', 'Q057', 'Q058', 'Q059', 'Q060', 'Q061', 'Q062', 'Q063', 'Q064',
							 'Q068', 'Q069', 'Q0700', 'Q0701', 'Q0702', 'Q0703', 'Q078', 'Q079')
									 then clm_nr_spinabif=1; label clm_nr_spinabif="Spina bifida and other congenital anomalies of the nervous system";	/* Spina bifida and other congenital anomalies of the nervous system */
	if 	dx in				('F070', 'F0781', 'F0789', 'F482', 'S04011S', 'S04012S', 'S04019S', 'S0402XS', 'S04031S', 'S04032S', 'S04039S', 'S04041S', 'S04042S', 'S04049S',
							 'S0410XS', 'S0411XS', 'S0412XS', 'S0420XS', 'S0421XS', 'S0422XS', 'S0430XS', 'S0431XS', 'S0432XS', 'S0440XS', 'S0441XS', 'S0442XS', 'S0450XS',
							 'S0451XS', 'S0452XS', 'S0460XS', 'S0461XS', 'S0462XS', 'S0470XS', 'S0471XS', 'S0472XS', 'S04811S', 'S04812S', 'S04819S', 'S04891S', 'S04892S',
							 'S04899S', 'S049XXS', 'S060X0S', 'S060X1S', 'S060X2S', 'S060X3S', 'S060X4S', 'S060X5S', 'S060X6S', 'S060X7S', 'S060X8S', 'S060X9S', 'S061X0S',
							 'S061X1S', 'S061X2S', 'S061X3S', 'S061X4S', 'S061X5S', 'S061X6S', 'S061X7S', 'S061X8S', 'S061X9S', 'S062X0S', 'S062X1S', 'S062X2S', 'S062X3S',
							 'S062X4S', 'S062X5S', 'S062X6S', 'S062X7S', 'S062X8S', 'S062X9S', 'S06300S', 'S06301S', 'S06302S', 'S06303S', 'S06304S', 'S06305S', 'S06306S',
							 'S06307S', 'S06308S', 'S06309S', 'S06310S', 'S06311S', 'S06312S', 'S06313S', 'S06314S', 'S06315S', 'S06316S', 'S06317S', 'S06318S', 'S06319S',
							 'S06320S', 'S06321S', 'S06322S', 'S06323S', 'S06324S', 'S06325S', 'S06326S', 'S06327S', 'S06328S', 'S06329S', 'S06330S', 'S06331S', 'S06332S',
							 'S06333S', 'S06334S', 'S06335S', 'S06336S', 'S06337S', 'S06338S', 'S06339S', 'S06340S', 'S06341S', 'S06342S', 'S06343S', 'S06344S', 'S06345S',
							 'S06346S', 'S06347S', 'S06348S', 'S06349S', 'S06350S', 'S06351S', 'S06352S', 'S06353S', 'S06354S', 'S06355S', 'S06356S', 'S06357S', 'S06358S',
							 'S06359S', 'S06360S', 'S06361S', 'S06362S', 'S06363S', 'S06364S', 'S06365S', 'S06366S', 'S06367S', 'S06368S', 'S06369S', 'S06370S', 'S06371S',
							 'S06372S', 'S06373S', 'S06374S', 'S06375S', 'S06376S', 'S06377S', 'S06378S', 'S06379S', 'S06380S', 'S06381S', 'S06382S', 'S06383S', 'S06384S',
							 'S06385S', 'S06386S', 'S06387S', 'S06388S', 'S06389S', 'S064X0S', 'S064X1S', 'S064X2S', 'S064X3S', 'S064X4S', 'S064X5S', 'S064X6S', 'S064X7S',
							 'S064X8S', 'S064X9S', 'S065X0S', 'S065X1S', 'S065X2S', 'S065X3S', 'S065X4S', 'S065X5S', 'S065X6S', 'S065X7S', 'S065X8S', 'S065X9S', 'S066X0S',
							 'S066X1S', 'S066X2S', 'S066X3S', 'S066X4S', 'S066X5S', 'S066X6S', 'S066X7S', 'S066X8S', 'S066X9S', 'S06810S', 'S06811S', 'S06812S', 'S06813S',
							 'S06814S', 'S06815S', 'S06816S', 'S06817S', 'S06818S', 'S06819S', 'S06820S', 'S06821S', 'S06822S', 'S06823S', 'S06824S', 'S06825S', 'S06826S',
							 'S06827S', 'S06828S', 'S06829S', 'S06890S', 'S06891S', 'S06892S', 'S06893S', 'S06894S', 'S06895S', 'S06896S', 'S06897S', 'S06898S', 'S06899S',
							 'S069X0S', 'S069X1S', 'S069X2S', 'S069X3S', 'S069X4S', 'S069X5S', 'S069X6S', 'S069X7S', 'S069X8S', 'S069X9S')
									 then clm_nr_traumbrain=1; label clm_nr_traumbrain="Traumatic brain injury and non-psychotic mental disorders due to brain damage";	/* Traumatic brain injury and non-psychotic mental disorders due to brain damage */
	if 	dx in				('G800', 'G801', 'G802', 'G803', 'G804', 'G808', 'G809')	 then clm_nr_cerebralp=1; label clm_nr_cerebralp="Cerebral palsy";	/* Cerebral palsy */
	if 	dx in				('G041', 'G114', 'G8100', 'G8101', 'G8102', 'G8103', 'G8104', 'G8110', 'G8111', 'G8112', 'G8113', 'G8114', 'G8190', 'G8191', 'G8192', 'G8193',
							 'G8194', 'G8220', 'G8221', 'G8222', 'G8250', 'G8251', 'G8252', 'G8253', 'G8254', 'G830', 'G8310', 'G8311', 'G8312', 'G8313', 'G8314', 'G8320',
							 'G8321', 'G8322', 'G8323', 'G8324', 'G8330', 'G8331', 'G8332', 'G8333', 'G8334', 'G834', 'G835', 'G8381', 'G8382', 'G8383', 'G8384', 'G8389',
							 'G839', 'I69031', 'I69032', 'I69033', 'I69034', 'I69039', 'I69041', 'I69042', 'I69043', 'I69044', 'I69049', 'I69051', 'I69052', 'I69053', 'I69054',
							 'I69059', 'I69061', 'I69062', 'I69063', 'I69064', 'I69065', 'I69069', 'I69131', 'I69132', 'I69133', 'I69134', 'I69139', 'I69141', 'I69142',
							 'I69143', 'I69144', 'I69149', 'I69151', 'I69152', 'I69153', 'I69154', 'I69159', 'I69161', 'I69162', 'I69163', 'I69164', 'I69165', 'I69169',
							 'I69231', 'I69232', 'I69233', 'I69234', 'I69239', 'I69241', 'I69242', 'I69243', 'I69244', 'I69249', 'I69251', 'I69252', 'I69253', 'I69254',
							 'I69259', 'I69261', 'I69262', 'I69263', 'I69264', 'I69265', 'I69269', 'I69331', 'I69332', 'I69333', 'I69334', 'I69339', 'I69341', 'I69342',
							 'I69343', 'I69344', 'I69349', 'I69351', 'I69352', 'I69353', 'I69354', 'I69359', 'I69361', 'I69362', 'I69363', 'I69364', 'I69365', 'I69369',
							 'I69831', 'I69832', 'I69833', 'I69834', 'I69839', 'I69841', 'I69842', 'I69843', 'I69844', 'I69849', 'I69851', 'I69852', 'I69853', 'I69854',
							 'I69859', 'I69861', 'I69862', 'I69863', 'I69864', 'I69865', 'I69869', 'I69931', 'I69932', 'I69933', 'I69934', 'I69939', 'I69941', 'I69942',
							 'I69943', 'I69944', 'I69949', 'I69951', 'I69952', 'I69953', 'I69954', 'I69959', 'I69961', 'I69962', 'I69963', 'I69964', 'I69965', 'I69969')
									 then clm_nr_mobility=1; label clm_nr_mobility="Mobility impairments"; /* Mobility impairments */
	if 	dx in				('G9611', 'S12000A', 'S12001A', 'S12100A', 'S12101A', 'S12200A', 'S12201A', 'S12300A', 'S12301A', 'S12400A', 'S12401A', 'S12500A', 'S12501A',
							 'S12600A', 'S12601A', 'S129XXA', 'S12000B', 'S12001B', 'S12100B', 'S12101B', 'S12200B', 'S12201B', 'S12300B', 'S12301B', 'S12400B', 'S12401B',
							 'S12500B', 'S12501B', 'S12600B', 'S12601B', 'S140XXA', 'S140XXS', 'S14101A', 'S14102A', 'S14103A', 'S14104A', 'S14105A', 'S14106A', 'S14107A',
							 'S14108A', 'S14109A', 'S14111A', 'S14112A', 'S13113A', 'S14114A', 'S14115A', 'S14116A', 'S14117A', 'S14118A', 'S14119A', 'S14121A', 'S14122A',
							 'S14123A', 'S14124A', 'S14125A', 'S14126A', 'S14127A', 'S14128A', 'S14129A', 'S14131A', 'S14132A', 'S14133A', 'S14134A', 'S14135A', 'S14136A',
							 'S14137A', 'S14138A', 'S14139A', 'S14141A', 'S14142A', 'S14143A', 'S14144A', 'S14145A', 'S14146A', 'S14147A', 'S14148A', 'S14149A', 'S14151A',
							 'S14152A', 'S14153A', 'S14154A', 'S14155A', 'S14156A', 'S14157A', 'S14158A', 'S14159A', 'S14101S', 'S14102S', 'S14103S', 'S14104S', 'S14105S',
							 'S14106S', 'S14107S', 'S14108S', 'S14109S', 'S14111S', 'S14112S', 'S14113S', 'S14114S', 'S14115S', 'S14116S', 'S14117S', 'S14118S', 'S14119S',
							 'S14121S', 'S14122S', 'S14123S', 'S14124S', 'S14125S', 'S14126S', 'S14127S', 'S14128S', 'S14129S', 'S14131S', 'S14132S', 'S14133S', 'S14134S',
							 'S14135S', 'S14136S', 'S14137S', 'S14138S', 'S14139S', 'S14141S', 'S14142S', 'S14143S', 'S14144S', 'S14145S', 'S14146S', 'S14147S', 'S14148S',
							 'S14149S', 'S14151S', 'S14152S', 'S14153S', 'S14154S', 'S14155S', 'S14156S', 'S14157S', 'S14158S', 'S14159S', 'S22009A', 'S22019A', 'S22029A',
							 'S22039A', 'S22049A', 'S22059A', 'S22069A', 'S22079A', 'S22089A', 'S22009B', 'S22019B', 'S22029B', 'S22039B', 'S22049B', 'S22059B', 'S22069B',
							 'S22079B', 'S22089B', 'S240XXA', 'S24101A', 'S24102A', 'S24103A', 'S24104A', 'S24109A', 'S24111A', 'S24112A', 'S24113A', 'S24114A', 'S24119A',
							 'S24131A', 'S24132A', 'S24133A', 'S24134A', 'S24139A', 'S24141A', 'S24142A', 'S24143A', 'S24144A', 'S24149A', 'S24151A', 'S24152A', 'S24153A',
							 'S24154A', 'S24159A', 'S240XXS', 'S24101S', 'S24102S', 'S24103S', 'S24104S', 'S24109S', 'S24111S', 'S24112S', 'S24113S', 'S24114S', 'S24119S',
							 'S24131S', 'S24132S', 'S24133S', 'S24134S', 'S24139S', 'S24141S', 'S24142S', 'S24143S', 'S24144S', 'S24149S', 'S24151S', 'S24152S', 'S24153S',
							 'S24154S', 'S24159S', 'S32009A', 'S32019A', 'S32029A', 'S32039A', 'S32049A', 'S32059A', 'S32009B', 'S32019B', 'S32029B', 'S32039B', 'S32049B',
							 'S32059B', 'S3210XA', 'S322XXA', 'S3210XB', 'S322XXB', 'S3401XA', 'S3402XA', 'S34101A', 'S34102A', 'S34103A', 'S34104A', 'S34105A', 'S34109A',
							 'S34111A', 'S34112A', 'S34113A', 'S34114A', 'S34115A', 'S34119A', 'S34121A', 'S34122A', 'S34123A', 'S34124A', 'S34125A', 'S34129A', 'S34131A',
							 'S34132A', 'S34139A', 'S343XXA', 'S3401XS', 'S3402XS', 'S34101S', 'S34102S', 'S34103S', 'S34104S', 'S34105S', 'S34109S', 'S34111S', 'S34112S',
							 'S34113S', 'S34114S', 'S34115S', 'S34119S', 'S34121S', 'S34122S', 'S34123S', 'S34124S', 'S34125S', 'S34129S', 'S34131S', 'S34132S', 'S34139S')
									 then clm_nr_spinal=1; label clm_nr_spinal="Spinal Cord Injury"; /* Spinal Cord Injury */

	count_nr = sum(of clm_nr_:);
	if count_nr gt 0 then clm_neurological=1;

	/*** Intellectual and Other Disabilities ***/
	clm_int_intd=0; clm_int_learn=0; clm_int_blind=0; clm_int_deaf=0;

	if 	dx in ('E7871', 'E7872', 'F70', 'F71', 'F72', 'F73', 'F78', 'F79', 'P043', 'Q860', 'Q871', 'Q8711', 'Q8719', 'Q872', 'Q873', 'Q875', 'Q8781', 'Q8789',
			   'Q897', 'Q898', 'Q900', 'Q901', 'Q902', 'Q909', 'Q910', 'Q911', 'Q912', 'Q913', 'Q914', 'Q915', 'Q916', 'Q917', 'Q920', 'Q921', 'Q922', 'Q925',
			   'Q9261', 'Q9262', 'Q927', 'Q928', 'Q929', 'Q930', 'Q931', 'Q932', 'Q933', 'Q934', 'Q935', 'Q9351', 'Q93529', 'Q937', 'Q9381', 'Q9388', 'Q9389',
			   'Q939', 'Q952', 'Q953', 'Q992')
			    then clm_int_intd=1; label clm_int_intd="Intellectual Disabilities and Related Conditions";	/* Intellectual Disabilities and Related Conditions */
	if 	dx in ('F800', 'F801', 'F802', 'F804', 'F8081', 'F8082', 'F8089', 'F809', 'F810', 'F812', 'F8181', 'F8189', 'F819', 'F82', 'H9325', 'R480')
				then clm_int_learn=1; label clm_int_learn="Learning Disabilities";	/* Learning Disabilities */
	if 	dx in  ('H540', 'H540X33', 'H540X34', 'H540X35', 'H540X43', 'H540X44', 'H540X45', 'H540X53', 'H540X54', 'H540X55', 'H5410', 'H5411', 'H541131',
				'H541132', 'H541141', 'H541142', 'H541151', 'H541152', 'H5412', 'H541213', 'H541214', 'H541215', 'H541223', 'H541224', 'H541225', 'H542',
				'H542X11', 'H542X12', 'H542X21', 'H542X22', 'H543', 'H548')
				then clm_int_blind=1; label clm_int_blind="Sensory Blindness and Visual Impairment";	/* Sensory Blindness and Visual Impairment  */
	if 	dx in	('H903', 'H9041', 'H9042', 'H905', 'H906', 'H9071', 'H9072', 'H908', 'H90A21', 'H90A22', 'H90A31', 'H90A32', 'H9101', 'H9102', 'H9103', 'H9109',
				 'H913', 'H918X1', 'H918X2', 'H918X3', 'H918X9', 'H9190', 'H9191', 'H9192', 'H9193')
				 then clm_int_deaf=1; label clm_int_deaf="Sensory Deafness and Hearing Impairment";	/* Sensory Deafness and Hearing Impairment */

	count_int = sum(of clm_int_:);
	if count_int gt 0 then clm_intellectual=1;

	/*** Cancer ***/
	clm_cncr_headneck=0; clm_cncr_gi=0; clm_cncr_resp=0; clm_cncr_bone=0; clm_cncr_melanoma=0; clm_cncr_br_genital=0; clm_cncr_urinary=0; clm_cncr_brain=0; clm_cncr_blood=0; clm_cncr_other=0;
	clm_cncr_skinoth=0;

	if substr(dx,1,3) in ('C00', 'C01', 'C02', 'C03', 'C04', 'C05', 'C06', 'C07', 'C08', 'C09', 'C10', 'C11', 'C12', 'C13', 'C14', 'D00') then clm_cncr_headneck=1;
	if substr(dx,1,3) in ('C16','C18', 'C19', 'C20', 'C21', 'C25', 'C15', 'C17', 'C22', 'C23', 'C24', 'C48','D01') then clm_cncr_gi=1; 
	if substr(dx,1,4) in ('C268', 'C260', 'C269', 'C451') then clm_cncr_gi=1;
	if substr(dx,1,3) in ('C34', 'C30', 'C31', 'C33', 'C38', 'C39', 'C32','D02') then clm_cncr_resp=1;
	if substr(dx,1,4) = 'C450' then clm_cncr_resp=1;
	if substr(dx,1,3) in ('C40', 'C41', 'C47', 'C49') then clm_cncr_bone=1;
	if substr(dx,1,4) in ('C380', 'C452') then clm_cncr_bone=1;
	if substr(dx,1,3) in ('C43', 'D03') then clm_cncr_melanoma=1;
	if substr(dx,1,3) in ('C50','C53','C54','C56','C61','C51', 'C52', 'C55', 'C57', 'C58', 'C60', 'C62', 'C63', 'D05', 'D06', 'D07') then clm_cncr_br_genital=1;
	if substr(dx,1,3) in ('C67', 'C64', 'C65', 'C66', 'C68') then clm_cncr_urinary=1;
	if substr(dx,1,4) in ('D090', 'D091') then clm_cncr_urinary=1;
	if substr(dx,1,3) in ('C70', 'C71', 'C72') then clm_cncr_brain=1;
	if substr(dx,1,3) in ('C81','C82', 'C84', 'C85', 'C86', 'C88', 'C91', 'C92', 'C93', 'C94', 'C95') then clm_cncr_blood=1;
	if substr(dx,1,4) in ('C900', 'C902', 'C901', 'C963') then clm_cncr_blood=1;
	if substr(dx,1,3) in ('C44', 'D04') then clm_cncr_skinoth=1;
	if substr(dx,1,3) in ('C37', 'C46', 'C69', 'C73', 'C74', 'C75', 'C76', 'C77', 'C78', 'C79', 'C80') then clm_cncr_other=1;
	if substr(dx,1,4) in ('C261', 'C457', 'C459', 'C960', 'C961', 'C962', 'C967', 'C968', 'C979', 'C999', 'D097', 'D099') then clm_cncr_other=1;

	count_cancer=sum(of clm_cncr_headneck clm_cncr_gi clm_cncr_resp clm_cncr_bone clm_cncr_melanoma clm_cncr_br_genital clm_cncr_urinary clm_cncr_brain clm_cncr_blood clm_cncr_other clm_cncr_skinoth);
	if count_cancer gt 0 then clm_cancer=1; 

	if clm_cancer=1 and substr(dx,4,1) in ('','1','2','3','4','5','6','7','8','9','0') then cncr_num4=1;

	/*** Major CCs not from CCW - Lung Disease, Specified Heart Arrhythmias ***/
	clm_cc_arrhy=0; clm_cc_pf=0;

	if dx in ('I440', 'I441', 'I442', 'I4430', 'I4439', 'I444', 'I445', 'I4460', 'I4469', 'I447', 'I450', 'I4510', 'I4519', 'I452', 'I453',
	 		  'I454', 'I455', 'I456', 'I4581', 'I4589', 'I459', 'I470', 'I471', 'I472', 'I479', 'I480', 'I481', 'I4811', 'I4819', 'I482', 'I4820',
			  'I4821', 'I483', 'I484', 'I4891', 'I4892', 'I4901', 'I4902', 'I491', 'I492', 'I492', 'I493', 'I4940', 'I4949', 'I495', 'I498', 'I499',
			  'Q246', 'R000', 'R001', 'R002', 'T82110A', 'T82111A', 'T82120A', 'T82121A', 'T82190A', 'T82191A') then clm_cc_arrhy=1; label clm_cc_arrhy="Major CC: Arrhythmias";
	
	if dx in ('D8686', 'D8682', 'D8685', 'D860', 'D863', 'D861', 'D8683', 'D8689', 'D8681', 'D8687', 'D869', 'D862', 'D8684',
		  'J40', 'J410', 'J411', 'J441', 'J440', 'J418', 'J42', 'J439', 'J438', 'J432', 'J431', 'J430', 'J4550', 'J4540', 'J4530',
		  'J4520', 'J4552', 'J4542', 'J4532', 'J4522', 'J4551', 'J4541', 'J4531', 'J4521', 'J45990', 'J45991', 'J45998', 'J45909',
		  'J45902', 'J45901', 'J479', 'J471', 'J470', 'J670', 'J671', 'J672', 'J673', 'J674', 'J675', 'J676', 'J677', 'J678',
		  'J679', 'J449', 'J60', 'J61', 'J628', 'J620', 'J636', 'J635', 'J634', 'J633', 'J632', 'J631', 'J630', 'J668', 'J662',
		  'J661', 'J660', 'J65', 'J64', 'J680', 'J681', 'J682', 'J683', 'J684', 'J689', 'J688', 'J700', 'J701', 'J705', 'J708',
		  'J704', 'J703', 'J702', 'J709', 'J8489', 'J8417', 'J8410', 'J8401', 'J8403', 'J8402', 'J84111', 'J84112', 'J84113',
		  'J84114', 'J84115', 'J842', 'J84116', 'J84117', 'J8481', 'J8482', 'J84841', 'J84842', 'J8483', 'J84843', 'J84848', 'J8409',
		  'J849', 'J99', 'J982', 'J983', 'J82', 'B4481', 'M0510', 'B909', 'M05111', 'M05112', 'M05119', 'M05121', 'M05122', 'M05129',
		  'M05131', 'M05132', 'M05139', 'M05141', 'M05142', 'M05149', 'M05151', 'M05152', 'M05159', 'M05161', 'M05162', 'M05169',
		  'M05171', 'M05172', 'M05179', 'M0519', 'M3481', 'P270', 'P271', 'P278', 'P279') then clm_cc_pf=1; label clm_cc_pf="Major CC: Lung Disease";

	if clm_autoimmune=1 or clm_raregenetic=1 or clm_neurological=1 or clm_intellectual=1 or clm_cancer=1 or clm_cc_arrhy=1 or clm_cc_pf=1
		or clm_check_rg=1 or clm_check_ai=1;
run;

proc sql;
	create table all_cat_clms as
	select bene_id, sum(clm_autoimmune) as clm_autoimmune, sum(clm_raregenetic) as clm_raregenetic,
		sum(clm_neurological) as clm_neurological, sum(clm_intellectual) as clm_intellectual,
		sum(clm_cancer) as clm_cancer, sum(clm_ai_rheumarth) as clm_ai_rheumarth,
		sum(clm_ai_psoriasis) as clm_ai_psoriasis, sum(clm_ai_ms) as clm_ai_ms, sum(clm_ai_sle) as clm_ai_sle,
		sum(clm_ai_mctd) as clm_ai_mctd, sum(clm_ai_amyloi) as clm_ai_amyloi, sum(clm_ai_sclero) as clm_ai_sclero,
		sum(clm_ai_ibd) as clm_ai_ibd, sum(clm_ai_addison) as clm_ai_addison,
		sum(clm_ai_sjogren) as clm_ai_sjogren, sum(clm_ai_myasth) as clm_ai_myasth,
		sum(clm_ai_asd) as clm_ai_asd, sum(clm_ai_anky) as clm_ai_anky,
		sum(clm_ai_behcet) as clm_ai_behcet, sum(clm_ai_cidp) as clm_ai_cidp,
		sum(clm_ai_crest) as clm_ai_crest, sum(clm_ai_uctd) as clm_ai_uctd,
		sum(clm_ai_pbc) as clm_ai_pbc, sum(clm_ai_psc) as clm_ai_psc,
		sum(clm_ai_derma) as clm_ai_derma, sum(clm_ai_discoid) as clm_ai_discoid,
		sum(clm_rg_cf) as clm_rg_cf, sum(clm_rg_muscdyst) as clm_rg_muscdyst,
		sum(clm_rg_hemophilia) as clm_rg_hemophilia, sum(clm_rg_huntington) as clm_rg_huntington,
		sum(clm_rg_downsyn) as clm_rg_downsyn, sum(clm_rg_fragile) as clm_rg_fragile,
		sum(clm_rg_glycogen) as clm_rg_glycogen, sum(clm_rg_charcot) as clm_rg_charcot,
		sum(clm_rg_angelman) as clm_rg_angelman, sum(clm_rg_vonw) as clm_rg_vonw,
		sum(clm_rg_sickle) as clm_rg_sickle, sum(clm_rg_taysachs) as clm_rg_taysachs,
		sum(clm_rg_hemochr) as clm_rg_hemochr, sum(clm_rg_digeorges) as clm_rg_digeorges,
		sum(clm_rg_criduchat) as clm_rg_criduchat, sum(clm_rg_canavan) as clm_rg_canavan,
		sum(clm_rg_neurofib) as clm_rg_neurofib, sum(clm_rg_pkd) as clm_rg_pkd, sum(clm_rg_prader) as clm_rg_prader,
		sum(clm_rg_famil) as clm_rg_famil, sum(clm_rg_turner) as clm_rg_turner, sum(clm_rg_spinmusc) as clm_rg_spinmusc,
		sum(clm_rg_als) as clm_rg_als, sum(clm_nr_spinabif) as clm_nr_spinabif,
		sum(clm_nr_traumbrain) as clm_nr_traumbrain, sum(clm_nr_cerebralp) as clm_nr_cerebralp,
		sum(clm_nr_mobility) as clm_nr_mobility, sum(clm_nr_spinal) as clm_nr_spinal,
		sum(clm_int_intd) as clm_int_intd, sum(clm_int_learn) as clm_int_learn, sum(clm_int_blind) as clm_int_blind,
		sum(clm_int_deaf) as clm_int_deaf, sum(clm_cncr_headneck) as clm_cncr_headneck,
		sum(clm_cncr_gi) as clm_cncr_gi, sum(clm_cncr_resp) as clm_cncr_resp, sum(clm_cncr_bone) as clm_cncr_bone,
		sum(clm_cncr_melanoma) as clm_cncr_melanoma, sum(clm_cncr_br_genital) as clm_cncr_br_genital,
		sum(clm_cncr_urinary) as clm_cncr_urinary, sum(clm_cncr_brain) as clm_cncr_brain,
		sum(clm_cncr_blood) as clm_cncr_blood, sum(clm_cncr_skinoth) as clm_cncr_skinoth,
		sum(clm_cncr_other) as clm_cncr_other,
		sum(clm_cc_arrhy) as clm_cc_arrhy, sum(clm_cc_pf) as clm_cc_pf,
		sum(clm_check_rg) as clm_check_rg, sum(clm_check_ai) as clm_check_ai
	from all_codes_dx
	group by bene_id;
quit;

proc sql; drop table all_codes_dx; quit;

/* bene level file with 1/0 indicators for all conditions */
data dataout.all_clm_cat_&pyr.;
	set all_cat_clms;

	if 	clm_autoimmune >0 then clm_autoimmune=1;
	if 	clm_raregenetic >0 then clm_raregenetic=1;
	if 	clm_neurological >0 then clm_neurological=1;
	if 	clm_intellectual >0 then clm_intellectual=1;
	if 	clm_cancer >0 then clm_cancer=1;
	if 	clm_ai_rheumarth >0 then clm_ai_rheumarth=1;
	if 	clm_ai_psoriasis >0 then clm_ai_psoriasis=1;
	if 	clm_ai_ms >0 then clm_ai_ms=1;
	if 	clm_ai_sle >0 then clm_ai_sle=1;
	if 	clm_ai_mctd >0 then clm_ai_mctd=1;
	if 	clm_ai_amyloi >0 then clm_ai_amyloi=1;
	if 	clm_ai_sclero >0 then clm_ai_sclero=1;
	if 	clm_ai_ibd >0 then clm_ai_ibd=1;
	if 	clm_ai_addison >0 then clm_ai_addison=1;
	if 	clm_ai_sjogren >0 then clm_ai_sjogren=1;
	if 	clm_ai_myasth >0 then clm_ai_myasth=1;
	if 	clm_ai_asd >0 then clm_ai_asd=1;
	if 	clm_ai_anky >0 then clm_ai_anky=1;
	if 	clm_ai_behcet >0 then clm_ai_behcet=1;
	if 	clm_ai_cidp >0 then clm_ai_cidp=1;
	if 	clm_ai_crest >0 then clm_ai_crest=1;
	if 	clm_ai_uctd >0 then clm_ai_uctd=1;
	if 	clm_ai_pbc >0 then clm_ai_pbc=1;
	if 	clm_ai_psc >0 then clm_ai_psc=1;
	if 	clm_ai_derma >0 then clm_ai_derma=1;
	if 	clm_ai_discoid >0 then clm_ai_discoid=1;
	if 	clm_rg_cf >0 then clm_rg_cf=1;
	if 	clm_rg_muscdyst >0 then clm_rg_muscdyst=1;
	if 	clm_rg_hemophilia >0 then clm_rg_hemophilia=1;
	if 	clm_rg_huntington >0 then clm_rg_huntington=1;
	if 	clm_rg_downsyn >0 then clm_rg_downsyn=1;
	if 	clm_rg_fragile >0 then clm_rg_fragile=1;
	if 	clm_rg_glycogen >0 then clm_rg_glycogen=1;
	if 	clm_rg_charcot >0 then clm_rg_charcot=1;
	if 	clm_rg_angelman >0 then clm_rg_angelman=1;
	if 	clm_rg_vonw >0 then clm_rg_vonw=1;
	if 	clm_rg_sickle >0 then clm_rg_sickle=1;
	if 	clm_rg_taysachs >0 then clm_rg_taysachs=1;
	if 	clm_rg_hemochr >0 then clm_rg_hemochr=1;
	if 	clm_rg_digeorges >0 then clm_rg_digeorges=1;
	if 	clm_rg_criduchat >0 then clm_rg_criduchat=1;
	if 	clm_rg_canavan >0 then clm_rg_canavan=1;
	if 	clm_rg_neurofib >0 then clm_rg_neurofib=1;
	if 	clm_rg_pkd >0 then clm_rg_pkd=1;
	if 	clm_rg_prader >0 then clm_rg_prader=1;
	if 	clm_rg_famil >0 then clm_rg_famil=1;
	if 	clm_rg_turner >0 then clm_rg_turner=1;
	if 	clm_rg_spinmusc >0 then clm_rg_spinmusc=1;
	if 	clm_rg_als >0 then clm_rg_als=1;
	if 	clm_nr_spinabif >0 then clm_nr_spinabif=1;
	if 	clm_nr_traumbrain >0 then clm_nr_traumbrain=1;
	if 	clm_nr_cerebralp >0 then clm_nr_cerebralp=1;
	if 	clm_nr_mobility >0 then clm_nr_mobility=1;
	if 	clm_nr_spinal >0 then clm_nr_spinal=1;
	if 	clm_int_intd >0 then clm_int_intd=1;
	if 	clm_int_learn >0 then clm_int_learn=1;
	if 	clm_int_blind >0 then clm_int_blind=1;
	if 	clm_int_deaf >0 then clm_int_deaf=1;
	if 	clm_cncr_headneck >0 then clm_cncr_headneck=1;
	if 	clm_cncr_gi >0 then clm_cncr_gi=1;
	if 	clm_cncr_resp >0 then clm_cncr_resp=1;
	if 	clm_cncr_bone >0 then clm_cncr_bone=1;
	if 	clm_cncr_melanoma >0 then clm_cncr_melanoma=1;
	if 	clm_cncr_br_genital >0 then clm_cncr_br_genital=1;
	if 	clm_cncr_urinary >0 then clm_cncr_urinary=1;
	if 	clm_cncr_brain >0 then clm_cncr_brain=1;
	if 	clm_cncr_blood >0 then clm_cncr_blood=1;
	if 	clm_cncr_skinoth >0 then clm_cncr_skinoth=1;
	if 	clm_cncr_other >0 then clm_cncr_other=1;
	if 	clm_cc_arrhy >0 then clm_cc_arrhy=1;
	if 	clm_cc_pf >0 then clm_cc_pf=1;
	if 	clm_check_rg >0 then clm_check_rg=1;
	if 	clm_check_ai >0 then clm_check_ai=1;

	label clm_autoimmune="Autoimmune Diseases";
	label clm_raregenetic="Rare Genetic Disorders";
	label clm_neurological="Severe Neurological Disorders";
	label clm_intellectual="Intellectual or Other Disability";
	label clm_cancer="Cancer";
	label clm_ai_rheumarth="Rheumatoid arthritis";
	label clm_ai_psoriasis="Psoriasis/psoriatic arthritis";
	label clm_ai_ms="Multiple sclerosis and Transverse Myelitis";
	label clm_ai_sle="Systemic lupus erythematous (SLE)";
	label clm_ai_mctd="Mixed connective tissue disease";
	label clm_ai_amyloi="Amyloidosis";
	label clm_ai_sclero="Scleroderma";
	label clm_ai_ibd="Inflammatory bowel disease";
	label clm_ai_addison="Addison's disease";
	label clm_ai_sjogren="Sjogren's syndrome";
	label clm_ai_myasth="Myasthenia gravis";
	label clm_ai_asd="Adult's still disease";
	label clm_ai_anky="Ankylosing spondylitis";
	label clm_ai_behcet="Behcet's disease";
	label clm_ai_cidp="Chronic inflammatory demyelinating polyneuropathy";
	label clm_ai_crest="CREST syndrome";
	label clm_ai_uctd="Undifferentiated connective tissue disease";
	label clm_ai_pbc="Primary biliary cirrhosis";
	label clm_ai_psc="Primary sclerosing cholangitis";
	label clm_ai_derma="Dermatomyositis/Polymyositits";
	label clm_ai_discoid="Discoid lupus";
	label clm_rg_cf="Cystic fibrosis and other metabolic developmental disorders";
	label clm_rg_muscdyst="Duchenne muscular dystrophy and other muscular disorders";
	label clm_rg_hemophilia="Hemophilia";
	label clm_rg_huntington="Huntingtons disease and other movement disorders";
	label clm_rg_downsyn="Down syndrome";
	label clm_rg_fragile="Fragile X syndrome";
	label clm_rg_glycogen="Glycogen storage disorders";
	label clm_rg_charcot="Charcot-Marie-Tooth disease";
	label clm_rg_angelman="Angelman syndrome";
	label clm_rg_vonw="Von Williebrand disease";
	label clm_rg_sickle="Sickle cell disease";
	label clm_rg_taysachs="Tay Sachs disease";
	label clm_rg_hemochr="Hemochromatosis";
	label clm_rg_digeorges="DiGeorges syndrome";
	label clm_rg_criduchat="Cri du chat syndrome";
	label clm_rg_canavan="Canavan disease";
	label clm_rg_neurofib="Neurofibromatosis";
	label clm_rg_pkd="Polycystic kidney disease";
	label clm_rg_prader="Prader Willi Syndrome";
	label clm_rg_famil="Familial hypercholesterolemia";
	label clm_rg_turner="Turner syndrome";
	label clm_rg_spinmusc="Spinal muscular atrophy";
	label clm_rg_als="Amyotrophic lateral sclerosis";
	label clm_nr_spinabif="Spina bifida and other congenital anomalies of the nervous system";
	label clm_nr_traumbrain="Traumatic brain injury and non-psychotic mental disorders due to brain damage";
	label clm_nr_cerebralp="Cerebral palsy";
	label clm_nr_mobility="Mobility impairments";
	label clm_nr_spinal="Spinal Cord Injury";
	label clm_int_intd="Intellectual Disabilities and Related Conditions";
	label clm_int_learn="Learning Disabilities";
	label clm_int_blind="Sensory Blindness and Visual Impairment";
	label clm_int_deaf="Sensory Deafness and Hearing Impairment";
	label clm_cncr_headneck="Cancer - Head Neck";
	label clm_cncr_gi="Cancer - GI Related";
	label clm_cncr_resp="Cancer - Respiratory";
	label clm_cncr_bone="Cancer - Bones and Soft Tissue";
	label clm_cncr_melanoma="Cancer - Melanoma of Skin";
	label clm_cncr_br_genital="Cancer - Breast/Genital";
	label clm_cncr_urinary="Cancer - Urinary/Kidney";
	label clm_cncr_brain="Cancer - Brain and Other Central Nervous System";
	label clm_cncr_blood="Cancer - Blood/Leukemia/Lymphoma Cancer";
	label clm_cncr_skinoth="Cancer - Skin (Non-melanoma)";
	label clm_cncr_other="Cancer - Other";
	label clm_cc_arrhy="Major CC: Arrhythmias";
	label clm_cc_pf="Major CC: Lung Disease";
run;

proc freq data=dataout.all_clm_cat_&pyr.;
	table clm_: / missing;
run;
