/*** Program: Step3_add_ccw_and_combine.sas                                                      ***/
/*** Created: August 20, 2020                                                                    ***/
/*** Program description: Combine data from Frailty Index, Claims, and CCW/Other condition file, ***/
/***                      Assign to subpopulation based on hierarchy in documentation            ***/
/*** Need: frailty_score_&pyr._&yr. file created in Step1_claims_based_frailty_index.sas,		 ***/
/***       all_clm_cat file created in Step2_codes_majorcc_subpop.sas,                           ***/
/***       CCW and Other Chronic Conditions files from CMS                                       ***/

libname datain 'D:\'; * Location of outputs from Step1 and Step2;
libname dataout 'D:\'; * Location final segment file will be saved;
libname cc 'D:\'; * Location of CCW, Other Chronic Condition files from CMS;

%let pyr=2016; * Assign previous year - year all claims and indicators are based on ;
%let yr=2017;  * Assign current year - year the segments will be used               ;



/*** Merge Frailty Score File (which includes all benes in sample) and Conditions from Claims   ***/
proc sql;
	create table subpop_tmp1 as
	select a.*, b.*
	from datain.frailty_score_&pyr._&yr. a left join datain.all_clm_cat_&pyr. b
	on a.bene_id=b.bene_id;
quit;

/* Add CCW Chronic Conditions - pyr End of Year variables */
proc sql;
	create table subpop_tmp2 as
	select a.*, b.*
	from subpop_tmp1 a left join cc.mbsf_cc&pyr.(keep=bene_id AMI HYPERL HYPERT ISCHMCHT CHRNKIDN CHF DIABETES
													 STRKETIA DEPRESSN ALZHDMTA CNCRBRST CNCRCLRC CNCRPRST CNCRLUNG CNCRENDM) b
	on a.bene_id=b.bene_id;
quit;

/* Add Other Chronic Conditions - pyr End of Year variables */
proc sql;
	create table subpop_tmp3 as
	select a.*, b.*
	from subpop_tmp2 a left join cc.mbsf_otcc&pyr.(keep=bene_id PVD_MEDICARE LIVER_MEDICARE ALCO_MEDICARE DRUG_MEDICARE
													 OUD_ANY_MEDICARE OBESITY_MEDICARE HIVAIDS_MEDICARE BIPL_MEDICARE SCHIOT_MEDICARE
													 BRAINJ_MEDICARE CERPAL_MEDICARE CYSFIB_MEDICARE DEPSN_MEDICARE HEARIM_MEDICARE
													 INTDIS_MEDICARE LEUKLYMPH_MEDICARE MOBIMP_MEDICARE MULSCL_MEDICARE MUSDYS_MEDICARE
													 SCD_MEDICARE SPIBIF_MEDICARE SPIINJ_MEDICARE VISUAL_MEDICARE LEADIS_MEDICARE) b
	on a.bene_id=b.bene_id;
quit;

data subpop_tmp4(drop=AMI ALZHDMTA HYPERL HYPERT CHRNKIDN CHF ISCHMCHT DEPRESSN DIABETES STRKETIA ALCO_MEDICARE
				   BIPL_MEDICARE DRUG_MEDICARE OBESITY_MEDICARE HIVAIDS_MEDICARE LIVER_MEDICARE
				   OUD_ANY_MEDICARE PVD_MEDICARE SCHIOT_MEDICARE CNCRBRST CNCRCLRC CNCRPRST CNCRLUNG CNCRENDM
				   BRAINJ_MEDICARE CERPAL_MEDICARE CYSFIB_MEDICARE DEPSN_MEDICARE HEARIM_MEDICARE INTDIS_MEDICARE LEUKLYMPH_MEDICARE 
				   MOBIMP_MEDICARE MULSCL_MEDICARE MUSDYS_MEDICARE SCD_MEDICARE SPIBIF_MEDICARE SPIINJ_MEDICARE VISUAL_MEDICARE LEADIS_MEDICARE);
	set subpop_tmp3;

	if clm_check_rg=1 then do;
		clm_rg_angelman=1;
		clm_raregenetic=1;
	end;

	/* if missing from claims file, assign as 0 */
	array clm_dx {*} clm_autoimmune clm_raregenetic clm_neurological clm_intellectual clm_cancer
					clm_ai_rheumarth clm_ai_psoriasis clm_ai_ms clm_ai_sle clm_ai_mctd clm_ai_amyloi clm_ai_sclero
					clm_ai_ibd clm_ai_addison clm_ai_sjogren clm_ai_myasth clm_ai_asd clm_ai_anky clm_ai_behcet
					clm_ai_cidp clm_ai_crest clm_ai_uctd clm_ai_pbc clm_ai_psc clm_ai_derma clm_ai_discoid
					clm_rg_cf clm_rg_muscdyst clm_rg_hemophilia clm_rg_huntington clm_rg_downsyn clm_rg_fragile
					clm_rg_glycogen clm_rg_charcot clm_rg_angelman clm_rg_vonw clm_rg_sickle clm_rg_taysachs
					clm_rg_hemochr clm_rg_digeorges clm_rg_criduchat clm_rg_canavan clm_rg_neurofib clm_rg_pkd
					clm_rg_prader clm_rg_famil clm_rg_turner clm_rg_spinmusc clm_rg_als clm_nr_spinabif
					clm_nr_traumbrain clm_nr_cerebralp clm_nr_mobility clm_nr_spinal clm_int_intd clm_int_learn
					clm_int_blind clm_int_deaf clm_cncr_headneck clm_cncr_gi clm_cncr_resp clm_cncr_bone
					clm_cncr_melanoma clm_cncr_br_genital clm_cncr_urinary clm_cncr_brain clm_cncr_blood
					clm_cncr_other clm_cc_arrhy clm_cc_pf clm_cncr_skinoth;

	do i=1 to dim(clm_dx);
		if clm_dx{i}=. then clm_dx{i}=0; 
	end;

	/* create indicators based on fitting the claims requirement (even if enrollment requirement not met) */
	array ccwv {*} AMI ALZHDMTA HYPERL HYPERT CHRNKIDN CHF DIABETES ISCHMCHT DEPRESSN STRKETIA ALCO_MEDICARE
				   BIPL_MEDICARE DRUG_MEDICARE OBESITY_MEDICARE HIVAIDS_MEDICARE LIVER_MEDICARE
				   OUD_ANY_MEDICARE PVD_MEDICARE SCHIOT_MEDICARE CNCRBRST CNCRCLRC CNCRPRST CNCRLUNG CNCRENDM
				   BRAINJ_MEDICARE CERPAL_MEDICARE CYSFIB_MEDICARE DEPSN_MEDICARE HEARIM_MEDICARE INTDIS_MEDICARE LEUKLYMPH_MEDICARE 
				   MOBIMP_MEDICARE MULSCL_MEDICARE MUSDYS_MEDICARE SCD_MEDICARE SPIBIF_MEDICARE SPIINJ_MEDICARE VISUAL_MEDICARE LEADIS_MEDICARE;

	array ccwnew {*} CCW_AMI CCW_ALZHDMTA CCW_HYPERL CCW_HYPERT CCW_CHRNKIDN CCW_CHF CCW_DIABETES CCW_ISCHMCHT CCW_DEPRESSN
					 CCW_STRKETIA CCW_ALCO CCW_BIPL CCW_DRUG CCW_OBESITY CCW_HIVAIDS CCW_LIVER CCW_OUD CCW_PVD CCW_SCHIOT 
					 CCW_CNCRBRST CCW_CNCRCLRC CCW_CNCRPRST CCW_CNCRLUNG CCW_CNCRENDM
					 CCW_BRAINJ CCW_CERPAL CCW_CYSFIB CCW_DEPDIS CCW_HEARIM CCW_INTDIS CCW_LEUKLYMPH 
					 CCW_MOBIMP CCW_MULSCL CCW_MUSDYS CCW_SCD CCW_SPIBIF CCW_SPIINJ CCW_VISUAL CCW_LEARNDIS;

	do i=1 to dim(ccwv);
		if ccwv{i} in (1,3) then ccwnew{i}=1;
		 else ccwnew{i}=0; 
	end;

	/* Group CCW variables for Heart Disease, SMI, and Behavioral Disorders */
	if CCW_AMI=1 or CCW_ISCHMCHT=1 then CCW_heart=1; else CCW_heart=0;
	if CCW_DEPRESSN=1 or CCW_BIPL=1 or CCW_SCHIOT=1 then ccw_smi=1; else ccw_smi=0;
	if CCW_ALCO=1 or CCW_DRUG=1 or CCW_OUD=1 then ccw_behavioral=1; else ccw_behavioral=0;

	/* count number of Major CCs (out of 9) - 3+ will mean major comorbidity burden */
	num_major_ccs = sum(of clm_cc_arrhy clm_cc_pf CCW_heart ccw_chrnkidn ccw_chf CCW_STRKETIA
						CCW_liver ccw_pvd CCW_DIABETES);
run;

data subpop_tmp5;
	set subpop_tmp4;

	length segment $ 2 segment_desc $ 50;
	/* define segments 11-13 first, then get frailty top 25 from remaining 65+ benes */
	if ccw_hivaids=1 then do;
		segment='11';
		segment_desc="11 HIV/AIDS";
		fscore_final=.;
	end;
	else if clm_raregenetic=1 then do;
		segment='12';
		segment_desc="12 Rare genetic disorders";
		fscore_final=.;
	end;
	else if clm_neurological=1 then do;
		segment='13';
		segment_desc="13 Severe neurological disorders";
		fscore_final=.;
	end;

	/* dont want to consider those under 65 when assigning quartiles of frailty score */
	if age_&pyr. lt 65 then fscore_final=.; /* use this variable to get quartiles and identify top quartile as frail */
	if age_&pyr. lt 65 then score=.; /* use this variable to check which benes in segments 11-13 would have been assigned as frail - not used in final assignment */
run;

/* get quartiles of frailty score for those 65+ */
proc rank data=subpop_tmp5 out=subpop_tmp6 groups=4;
	var fscore_final score;
	ranks fscore_quart origscore_quart;
run;

/* assign remaining subpopulations */
data dataout.segments_&yr.;
	set subpop_tmp6;

	if fscore_quart=3 then frail_top25=1; else if fscore_quart in (0,1,2) then frail_top25=0;

	if segment in ('11','12','13') and origscore_quart=3 and age_&pyr. ge 65 then wouldbe_frail=1; else wouldbe_frail=0;

	if segment='' then do;
		/* Frail segments (should already be only 65+ but will check again just in case) */
		if age_&pyr. ge 65 and frail_top25=1 and CCW_ALZHDMTA=1 and num_major_ccs ge 3 then do;
			segment='01';
			segment_desc="01 Frail Major CC Alzh/Dementia";
		end;
		else if age_&pyr. ge 65 and frail_top25=1 and num_major_ccs ge 3 then do;
			segment='02';
			segment_desc="02 Frail w/ Major CC ";
		end;
		else if age_&pyr. ge 65 and frail_top25=1 then do;
			segment='03';
			segment_desc="03 Older adults Frail Only";
		end;
		/* Autoimmune */
		else if clm_autoimmune=1 then do;
			segment='04';
			segment_desc="04 Autoimmune disease";
		end;
		/* SMI */
		else if ccw_smi=1 and num_major_ccs ge 3 then do;
			segment='05';
			segment_desc="05 SMI with major comorbidity";
			if ccw_behavioral=1 then subsegment="A";
			 else subsegment="B";
		end;
		else if ccw_smi=1 then do;
			segment='06';
			segment_desc="06 SMI low/no comorbidity";
			if ccw_behavioral=1 then subsegment="A";
			 else subsegment="B";
		end;
		/* Behavioral Health */
		else if ccw_behavioral=1 then do;
			segment='07';
			segment_desc="07 Behavioral Issues";
			if num_major_ccs ge 3 then subsegment="A";
			 else subsegment="B";
		end;
		/* Adults with multiple major chronic conditions */
		else if num_major_ccs ge 3  then do;
			segment='08';
			segment_desc="08 Major CCs";
		end;
		/*People with cancer*/
		else if clm_cancer=1 then do;
			segment='09';
			segment_desc="09 Cancer";
		end;
		/*Adults with metabolic syndrome*/
		else if CCW_HYPERL=1 and CCW_HYPERT=1 and CCW_OBESITY=1 then do;
			segment='10';
			segment_desc="10 Metabolic Syndrome";
		end;
		/* New subpopulation - Intellectual/Other Disability */
		else if clm_intellectual=1 then do;
			segment='14';
			segment_desc="14 Intellectual/Other";
		end;
	end;
run;
